# PDS_AREAL (Planetary Data System AtmospheREs Archive Labeling)
Automated labeling of ground-based observations of Jupiter for the PDS Atmosphers node

### About
The Planetary Data System (PDS) is a NASA digital archive making high-quality data available to the research community and the public. This project is specific to the Atmospheres Node, which is one node of the PDS, and specific to ground-based observations of Jupiter within Glenn Orton’s Planetary Atmospheres group at JPL, although the functions have been created to allow usage beyond this specific project.

### Modules
This package contains modules divided into three categories: create, which allows creation of PDS-required, non-label documents (inventories and observation logs); new labels, which allows labeling of data and of observation logs; and utilities, which contains different functions for fixing common errors.

[![codeastro](https://img.shields.io/badge/Made%20at-Code/Astro-blueviolet.svg)](https://semaphorep.github.io/codeastro/) [![Documentation Status](https://readthedocs.org/projects/pds-areal/badge/?version=latest)](https://pds-areal.readthedocs.io/en/latest/?badge=latest)

